@@ -1,12 +1,3 @@
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
-
-
-#' @importFrom sjmisc typical_value
-#' @export
-sjmisc::typical_value
-
 #' @importFrom performance mse
 #' @export
 performance::mse
@@ -15,14 +6,18 @@ performance::mse
 #' @export
 performance::rmse
 
-#' @importFrom bayestestR ci
-#' @export
-bayestestR::ci
-
-#' @importFrom bayestestR equivalence_test
-#' @export
-bayestestR::equivalence_test
-
 #' @importFrom insight link_inverse
 #' @export
 insight::link_inverse
+
+#' @importFrom datawizard weighted_sd
+#' @export
+datawizard::weighted_sd
+
+#' @importFrom datawizard weighted_mean
+#' @export
+datawizard::weighted_mean
+
+#' @importFrom datawizard weighted_median
+#' @export
+datawizard::weighted_median
